@extends('template.master')

@section('title', 'App User Management')

@push('styles')
<link rel="stylesheet" href="//cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/4.5.2/css/bootstrap.css">
<link rel="stylesheet" href="//cdn.datatables.net/1.13.4/css/dataTables.bootstrap4.min.css">
<style>
    .dataTable {
        width: none !important;
    }

    .modal-content>.modal-body>p>img {
        object-fit: contain;
        width: 100% !important;
        height: 100% !important;
    }
</style>
@endpush
@section('content')

<div class=" mt-4">
    <div class="row justify-content-center">
        <div class="col-md-12">
            <div class="card card-secondary">
                <div class="card-header" style="background: #000000;color: #f0ac63 !important;">
                    <h3 class="card-title">App User Management</h3>
                    @if($group_subscription_id == 0  || $group_subscription_id == '')
                        <a href="{{ route('app.user.create') }}" class="btn float-right" style="background: #f0ac63;color: #000000 !important;">Add</a>
                    @endif
                    @if(isset($group_subscription_id) && !empty($group_subscription_id))
                        <a href="{{ route('group.subscription.index') }}" class="btn float-right" style="background: #f0ac63;color: #000000 !important;">Back</a>
                    @endif
                </div>
                <!-- /.card-header -->
                <div class="card-body">
                    @if(session()->has('message'))
                    <div class="alert alert-success alert-dismissible">
                        {{ session()->get('message') }}
                    </div>
                    @endif
                    <div class="row my-2">
                        <input type="hidden" value="{{ $group_subscription_id }}" name="group_subscription_id" id="group_subscription_id">
                        <div class="form-group col-sm-12 col-md-3">
                            <label><strong>Full Name </strong></label>
                            <input type="text" name="full_name" id="full_name" class="form-control" placeholder="Search Full Name">
                        </div>
                        <div class="form-group col-sm-12 col-md-3">
                            <label><strong>Email</strong></label>
                            <input type="text" name="email" id="email" class="form-control" placeholder="Search Email">

                        </div>
                        <div class="form-group col-sm-12 col-md-3">
                            <label><strong>Phone</strong></label>
                            <input type="text" name="phone_no" id="phone_no" class="form-control" placeholder="Search Phone">
                        </div>
                        <div class="form-group col-sm-12 col-md-3">
                            <label><strong>Company</strong></label>
                            <input type="text" name="company" id="company" class="form-control" placeholder="Search Company">
                        </div>
                        <div class="form-group col-sm-12 col-md-3">
                            <label><strong>Job Title</strong></label>
                            <input type="text" name="title" id="title" class="form-control" placeholder="Search Job Title">
                        </div>
                    </div>
                    <div class="table-responsive">
                    <table class="table table-bordered dt-responsive display" id="example" style="width:none !important;">
                        <thead>
                            <tr>
                                <!-- <th  class="never">App User Id.</th>
                                <th style="width: 10px" class="all">No.</th> -->
                                <th class="all" width="10%">Action</th>
                                <th class="all">Full Name</th>
                                <th  class="all">Job Title</th>
                                <th class="all">Email</th>
                                <th class="desktop">Phone</th>
                                <th class="desktop">Company</th>
                                <th  class="desktop">Subscription Level</th>
                                <th  class="desktop">Subscription Type</th>
                                <th  class="desktop">Subscription Date</th>
                                <th class="desktop">Is Group Subscription</th>
                                <th class="desktop">Status</th>
                            </tr>
                        </thead>
                        <tbody>
                        </tbody>
                    </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

@endsection
@push('child-scripts')
<script>
    $(document).ready(function() {
        $.ajaxSetup({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            }
        });
        let table = $('#example').DataTable({
            columnDefs: [{
                "defaultContent": "-",
                "targets": "_all"
            }],
            processing: true,
            serverSide: true,
            searching: false,
            info: false,
            paging : true,
            lengthChange : true,
            autoWidth : true,
            responsive:true,
            order:[1, 'asc'],
            ajax: {
                url: "{{ route('app.user.ajax.list') }}",
                method: "POST",
                data: function(d) {
                    d.full_name = $('#full_name').val();
                    d.email = $('#email').val();
                    d.company = $('#company').val();
                    d.title = $('#title').val();
                    d.phone_no = $('#phone_no').val();
                    d.group_subscription_id = $('#group_subscription_id').val();
                }
            },
            columns: [
                {
                    data: 'action',
                    name: 'action',
                    orderable: false,
                    searchable: false
                },
                {
                    data: 'full_name',
                    name: 'full_name',
                },
                {
                    data: 'title',
                    name: 'title'
                },
                {
                    data: 'email',
                    name: 'email'
                },
                {
                    data: 'phone_no',
                    name: 'phone_no'
                },
                {
                    data: 'company',
                    name: 'company'
                },
                {
                    data: 'subscription_id',
                    name: 'subscription_id'
                },
                {
                    data: 'subscription_type',
                    name: 'subscription_type'
                },
                {
                    data: 'subscription_start_date',
                    name: 'subscription_start_date'
                },
                {
                    data: 'is_group_subscription',
                    name: 'is_group_subscription',
                    orderable: false
                },
                {
                    data: 'app_user_status',
                    name: 'app_user_status'
                }
            ]

        });
        $('#full_name, #email, #company, #phone_no, #title').change(function() {
            redrawTable(table);
        });
    });

    function redrawTable(table) {
        table.draw();
    }

    function deleteRecord(obj) {
        $.ajaxSetup({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            }
        });
        var userURL = obj.data('url');
        var r = confirm("Are you sure you want to remove this App User?");
        if (r == true) {
            $('#delete_' + userURL).submit()
        }
    }
</script>
@endpush
