@extends('template.master')

@section('title', 'Group Transactions')

@push('styles')
<style>
    .dataTable {
        width: none !important;
    }
</style>
@endpush
@section('content')

<div class=" mt-4">
    <div class="row justify-content-center">
        <div class="col-md-12">
            <div class="card card-secondary">
                <div class="card-header" style="background: #000000;color: #f0ac63 !important;">
                    <h3 class="card-title">Group Transactions</h3>
                    @if(isset($group_subscription_id)  && !empty($group_subscription_id))
                        <a href="{{ route('group.subscription.index') }}" class="btn float-right" style="background: #f0ac63;color: #000000 !important;">Back</a>
                    @endif
                </div>
                <!-- /.card-header -->
                <div class="card-body">
                    @if(session()->has('message'))
                    <div class="alert alert-success alert-dismissible">
                        {{ session()->get('message') }}
                    </div>
                    @endif
                    <div class="row my-2">
                        <input type="hidden" value="{{ $group_subscription_id }}" name="group_subscription_id" id="group_subscription_id">
                        <div class="form-group col-sm-12 col-md-3">
                            <label><strong>Group Subscription</strong></label>
                            <input type="text" name="group_subscription_title" id="group_subscription_title" class="form-control" placeholder="Search Group Subscription">
                        </div>
                        <div class="form-group col-sm-12 col-md-3">
                            <label><strong>Subscription Level </strong></label>
                            <select id='subscription_id' name="subscription_id" class="form-control" required>
                                <option value="">Select Subscription Level</option>
                                @foreach($subscripation as $subscription_id => $subscription_name)
                                <option value="{{$subscription_id}}">{{$subscription_name}}</option>
                                @endforeach
                            </select>
                        </div>
                        <div class="form-group col-sm-12 col-md-3">
                            <label><strong>Subscription Type</strong></label>
                            <select name="subscription_type" id="subscription_type" class="form-control">
                                <option value="">Select Subscription Type</option>
                                <option value="1">Monthly</option>
                                <option value="2">Yearly</option>
                            </select>
                        </div>
                        <div class="form-group col-sm-12 col-md-3">
                            <label><strong>Start Date</strong></label>
                            <input type="text" name="subscription_start_date" id="subscription_start_date" class="form-control" placeholder="Search Start Date">
                        </div>
                        <div class="form-group col-sm-12 col-md-3">
                            <label><strong>End Date</strong></label>
                            <input type="text" name="subscription_end_date" id="subscription_end_date" class="form-control" placeholder="Search End Date">
                        </div>
                    </div>
                    <div class="table-responsive">
                        <table class="table table-bordered dt-responsive display" id="example" style="width:none !important">
                            <thead>
                                <tr>
                                    <th class="all" width="20%">Group Subscription</th>
                                    <th class="all" width="20%">Subscription Level</th>
                                    <th class="desktop" width="10%">Subscription Type</th>
                                    <th class="desktop" width="10%">Amount</th>
                                    <th class="desktop" width="15%">Start Date</th>
                                    <th class="desktop" width="15%">End Date</th>
                                    <th class="desktop"width="10%">Subscription Status</th>
                                </tr>
                            </thead>
                            <tbody>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
@push('child-scripts')
<script>
    $(document).ready(function() {
        $("#subscription_start_date, #subscription_end_date").datepicker({
            dateFormat: "yy-mm-dd"
        });
        $.ajaxSetup({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            }
        });

        let table = $('#example').DataTable({
            columnDefs: [{
                "defaultContent": "-",
                "targets": "_all"
            }],
            processing: true,
            serverSide: true,
            searching: false,
            info: false,
            paging: true,
            lengthChange: true,
            autoWidth: true,
            responsive: true,
            order: [0, 'asc'],
            ajax: {
                url: "{{ route('group.transaction.ajax.list') }}",
                method: "POST",
                data: function(d) {
                    d.group_subscription_title = $('#group_subscription_title').val();
                    d.subscription_id = $('#subscription_id').val();
                    d.subscription_type = $('#subscription_type').val();
                    d.subscription_start_date = $('#subscription_start_date').val();
                    d.amount = $('#amount').val();
                    d.group_subscription_id = $('#group_subscription_id').val();
                    d.subscription_end_date = $('#subscription_end_date').val();
                }
            },
            columns: [{
                    data: 'group_subscription_title',
                    name: 'group_subscription_title',
                },
                {
                    data: 'subscription_name',
                    name: 'subscription_name'
                },
                {
                    data: 'subscription_type',
                    name: 'subscription_type'
                },
                {
                    data: 'amount',
                    name: 'amount'
                },
                {
                    data: 'subscription_start_date',
                    name: 'subscription_start_date'
                },
                {
                    data: 'subscription_end_date',
                    name: 'subscription_end_date'
                },
                {
                    data: 'subscription_status',
                    name: 'subscription_status'
                }
            ]

        });
        $('#group_subscription_title, #subscription_id, #subscription_type, #subscription_start_date, #amount, #subscription_end_date').change(function() {
            redrawTable(table);
        });
    });

    function redrawTable(table) {
        table.draw();
    }
</script>
@endpush
