@extends('template.master')
@section('title', 'Spotlight Member Management')
@push('styles')
<style>
    .dataTable {
        width: none !important;
    }

    .modal-content>.modal-body>p>img {
        object-fit: contain;
        width: 100% !important;
        height: 100% !important;
    }
</style>
@endpush
@section('content')

<div class=" mt-4">
    <div class="row justify-content-center">
        <div class="col-md-12">
            <div class="card card-secondary">
                <div class="card-header" style="background: #000000;color: #f0ac63 !important;">
                    <h3 class="card-title">Spotlight Member Management</h3>
                    <a href="{{ route('spotlight.create') }}" class="btn float-right" style="background: #f0ac63;color: #000000 !important;">Add</a>
                </div>
                <!-- /.card-header -->
                <div class="card-body">
                    @if(session()->has('message'))
                    <div class="alert alert-success alert-dismissible">
                        {{ session()->get('message') }}
                    </div>
                    @endif
                    <div class="row my-2">
                        <div class="form-group col-sm-12 col-md-3">
                            <label><strong>Contact Email </strong></label>
                            <input type="text" name="spotlight_member_contact_email" id="spotlight_member_contact_email" class="form-control" placeholder="Search Contact Email">
                        </div>
                        <div class="form-group col-sm-12 col-md-3">
                            <label><strong>Contact Name </strong></label>
                            <input type="text" name="spotlight_member_contact_name" id="spotlight_member_contact_name" class="form-control" placeholder="Search Contact Name">

                        </div>
                        <div class="form-group col-sm-12 col-md-3">
                            <label><strong>Short Desc </strong></label>
                            <input type="text" name="spotlight_member_company_short_description" id="spotlight_member_company_short_description" class="form-control" placeholder="Search Short Desc">
                        </div>
                    </div>
                    <div class="table-responsive">
                    <table class="table table-bordered  dt-responsive display" id="example" style="width:none !important">
                        <thead>
                            <tr>
                                <!-- <th class="never">Id.</th>
                                <th style="width: 10px" class="all">No.</th> -->
                                <th class="all" width="10%">Action</th>
                                <th class="all" width="20%">Contact Name</th>
                                <th class="all" width="20%">Email</th>
                                <th class="desktop" width="30%">Short Desc</th>
                                <th class="desktop" width="10%">Status</th>
                                <th class="desktop" width="10%">Logo</th>
                            </tr>
                        </thead>
                        <tbody>
                        </tbody>
                    </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

@endsection
@push('child-scripts')
<script>
    $(document).ready(function() {
        $.ajaxSetup({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            }
        });
        let table = $('#example').DataTable({
            columnDefs: [{
                "defaultContent": "-",
                "targets": "_all"
            }],
            processing: true,
            serverSide: true,
            searching: false,
            info: false,
            paging : true,
            lengthChange : true,
            autoWidth : true,
            responsive:true,
            order:[1, 'asc'],
            ajax: {
                url: "{{ route('spotlight.member.ajax.list') }}",
                method: "POST",
                data: function(d) {
                    d.spotlight_member_contact_email = $('#spotlight_member_contact_email').val();
                    d.spotlight_member_contact_name = $('#spotlight_member_contact_name').val();
                    d.spotlight_member_company_short_description = $('#spotlight_member_company_short_description').val();
                }
            },
            columns: [
                {
                    data: 'action',
                    name: 'action',
                    orderable: false,
                    searchable: false
                },
                {
                    data: 'spotlight_member_contact_name',
                    name: 'spotlight_member_contact_name'
                },
                {
                    data: 'spotlight_member_contact_email',
                    name: 'spotlight_member_contact_email'
                },
                {
                    data: 'spotlight_member_company_short_description',
                    name: 'spotlight_member_company_short_description'
                },
                {
                    data: 'spotlight_member_status',
                    name: 'spotlight_member_status'
                },
                {
                    data: 'spotlight_member_logo',
                    "render": function(data, type, JsonResultRow, meta) {
                        return '<img src="' + JsonResultRow.spotlight_member_company_logo + '" style="height:50px;width:50px;border:1px solid #000;">';
                    },
                    orderable: false
                }
            ]
        });
        $('#spotlight_member_contact_email, #spotlight_member_contact_name, #spotlight_member_company_short_description').change(function() {
            redrawTable(table);
        });
    });

    function redrawTable(table) {
        table.draw();
    }

    function deleteRecord(obj) {
        $.ajaxSetup({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            }
        });
        var userURL = obj.data('url');
        var r = confirm("Are you sure you want to remove this Spotlight Member?");
        if (r == true) {
            $('#delete_' + userURL).submit()
        }
    }
</script>
@endpush
